tiled.client.cache.Scorer
=========================

.. currentmodule:: tiled.client.cache

.. autoclass:: Scorer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Scorer.__init__
      ~Scorer.touch
   
   

   
   
   